
import UIKit
import MapKit

class ViewController: UIViewController, MKMapViewDelegate {
    @IBOutlet weak var mapView: MKMapView!
    var origin: MKMapItem!
    var destination: MKMapItem!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        let coordOrigin = CLLocationCoordinate2D(latitude: 40.7637825011971, longitude: -73.9731328627541)
        let placeOrigin = MKPlacemark(coordinate: coordOrigin)
        origin = MKMapItem(placemark: placeOrigin)
        
        let coordDestination = CLLocationCoordinate2D(latitude: 40.7523809365088, longitude: -73.9778321046893)
        let placeDestination = MKPlacemark(coordinate: coordDestination)
        destination = MKMapItem(placemark: placeDestination)
        
        let region = MKCoordinateRegion(center: coordOrigin, latitudinalMeters: 2000, longitudinalMeters: 2000)
        mapView.setRegion(region, animated: false)
        mapView.delegate = self
    }
    @IBAction func showDirections(_ sender: UIBarButtonItem) {
        let request = MKDirections.Request()
        request.source = origin
        request.destination = destination
        request.requestsAlternateRoutes = false
        
        let directions = MKDirections(request: request)
        directions.calculate(completionHandler: { (results, error) in
            if let routes = results?.routes {
                let route = routes.first!
                self.mapView.addOverlay(route.polyline, level: .aboveRoads)
            }
        })
    }
    func mapView(_ mapView: MKMapView, rendererFor overlay: MKOverlay) -> MKOverlayRenderer {
        let render = MKPolylineRenderer(overlay: overlay)
        render.strokeColor = UIColor.red
        return render
    }
    
}
